@@ -167,10 +167,10 @@ class LangCpp(SetProject):
 
 #include <iostream>
 
-int main(int argc, char **argv) {{
+int main(int argc, char **argv) {
 \t/* code here */
 \treturn 0;
-}}""")
+}""")
             else:
                 file.writelines(f"""// main file
 
@@ -183,8 +183,10 @@ using namespace std;
 
 #define ll long long
 #define lD long double
-#define rep(n) for (int i = 0; i < (int)n; i++)
-#define repl(n) for (ll i = 0; i < (ll)n; i++)
+#define PI 3.1415926535897932384626
+#define INF 1e9
+#define rep(i, n) for (int i = 0; i < (int)n; i++)
+#define repl(i, n) for (ll i = 0; i < (ll)n; i++)
 #define repd(i, n) for (int i = n - 1; i >= 0; i--)
 #define repld(i, n) for (ll i = n - 1; i >= 0; i--)
 #define loop(i,a,b) for (int i = (int)a; i < (int)b; i++)
@@ -195,27 +197,40 @@ using namespace std;
 #define rloopd(i,a,b) for (int i = (int)a; i >= b; i--)
 #define loopld(i,a,b) for (ll i = (ll)a; i > b; i--)
 #define rloopld(i,a,b) for (ll i = (ll)a; i >= b; i--)
-#define WL(t) while(t--)
+#define wl (t) while(t--)
 #define pb push_back
 #define eb emplace_back
 #define ab(a) (a < 0)?(-1*a):a
 #define mset(a,b,c) loop(i,0,b) a[i]=c
-#define asum(a,b,c) WL(b) {{ (c) += (a)[(b)]; }}
-#define F first
-#define S second
+#define asum(a,b,c) {{ int i = 0; c = 0; repd(i, b) c+=a[(i)]; }}
+#define fe first
+#define se second
 #define mp make_pair
 #define clr(x) x.clear()
 #define itoc(c) ((char)(((int)'0')+c))
 #define all(p) p.begin(),p.end()
-#define max(x,y) (x>y)?x:y
-#define min(x,y) (x<y)?x:y
+#define rall(p) (p).rbegin(),(p).rend()
+#define tr(c,it) for(__typeof__((c)).begin() it = (c).begin(); it != (c).end(); it++)
+#define trr(c,it) for(__typeof__((c)).rbegin() it = (c).rbegin(); it != (c).rend(); it++)
+#define present(c,x) ((c).find(x) != (c).end())  // container version, log(n) for set and map
+#define cpresent(c,x) (find(all(c),x) != (c).end())  // works for all container
+#define mx(x,y) ((x)>(y)?(x):(y))
+#define mn(x,y) ((x)<(y)?(x):(y))
 #define remax(a,b) (a = max(a,b))
 #define remin(a,b) (a = min(a,b))
 #define mid(s,e) (s+(e-s)/2)
-#define PQ(type) priority_queue<type>
-#define PQD(type) priority_queue<type,vector<type>,greater<type>>
-#define SZ(x) ((int)(x).size())
+#define mod(a,b) ((a)-((a)/(b))*(b))
+#define pq(type) priority_queue<type>
+#define pqd(type) priority_queue<type,vector<type>,greater<type>>
+#define umap unordered_map
+#define uset unordered_set
+#define sz(x) ((int)(x).size())
 #define inrange(i,a,b) ((i>=min(a,b)) && (i<=max(a,b)))
+#define cfp(x) \
+	cout << fixed << showpoint; \
+	cout << setprecision(x);
+#define nl "\\n"
+#define br cout << "\\n";
 
 #define fileI(name) \\
 	freopen(name".in", "r", stdin);
@@ -229,20 +244,50 @@ using namespace std;
 
 typedef vector<int> vi;
 typedef vector<vector<int>> vvi;
+typedef vector<string> vs;
+typedef vector<vector<string>> vvs;
+typedef vector<double> vd;
+typedef vector<vector<double>> vvd;
 typedef pair<ll, ll> pll;
 typedef pair<int, int> pii;
 typedef vector<pll> vpll;
 typedef vector<pii> vpii;
+mt19937_64 rang(chrono::high_resolution_clock::now().time_since_epoch().count());
+int rngi(int lim) {{
+	uniform_int_distribution<int> uid(0,lim-1);
+	return uid(rang);
+}}
+double rngr(double lim) {{
+	uniform_real_distribution<double> urd(0,lim-1);
+	return urd(rang);
+}}
 
 template<typename T> T gcd(T a, T b) {{ return (b?__gcd(a,b):a); }}
 template<typename T> T lcm(T a, T b) {{ return (a*(b/gcd(a,b))); }}
 
+inline void tokenize(const string& str, vs& out, const char&& delim) {{
+	stringstream ss(str);
+	string s;
+	while (getline(ss, s, delim)) out.pb(s);
+}}
+inline void tokenize(const string& str, vd& out, const char&& delim) {{
+	stringstream ss(str);
+	for (double i; ss >> i;) {{ out.pb(i); if (ss.peek() == delim) ss.ignore(); }}
+}}
+inline void tokenize(const string& str, vi& out, const char&& delim) {{
+	stringstream ss(str);
+	for (int i; ss >> i;) {{ out.pb(i); if (ss.peek() == ',') ss.ignore(); }}
+}}
+
 void solvethetestcase();
 
 signed main() {{
-	// comment when using scanf, printf \\
+	// comment when using scanf, printf
 	FAST_IO
 
+	// set the seed \
+	srand(chrono::high_resolution_clock::now().time_since_epoch().count());
+
 	// comment for input through console
 	fileI("input")
 
@@ -250,8 +295,8 @@ signed main() {{
 	// (uncomment for multiple test cases) \\
 	cin >> t;
 	loopl (testcase, 1, t + 1) {{
-		// (uncomment for codejam) \\
-		printf("Case #%lld: ", testcase);
+		// (uncomment for multiple test cases) \\
+		cout << "Case #" << testcase << ": ";
 		solvethetestcase();
     }}
 }}
@@ -348,7 +393,7 @@ clean:
         """general setup for setting up C++ lang project"""
         self.src.mkdir()
         Path.touch(self.mfile)
-        for_cp = input("is the setup for competitive coding? [y/n](no option is considered no): ")
+        for_cp = input("Is the setup for competitive coding? [y/n](no option is considered no): ")
         if for_cp == '' or for_cp == 'n':
             for_cp = False
         else:
@@ -365,7 +410,7 @@ clean:
                     file_name = input(str(count + 1) + ": ")
                     Path.touch(self.inc / (file_name + ".hpp"))
                     Path.touch(self.src / (file_name + ".cpp"))
-        self.compiler = input("Enter compiler[defualt is clang++]: ")
+        self.compiler = input("Enter compiler[default is clang++]: ")
         if not self.compiler:
             self.compiler = "clang++"
         LangCpp.__writeToFiles(self, for_cp)
